# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import enum

import winrt.system
from winrt._winrt_windows_devices_pointofservice import (
    SizeUInt32,
    BarcodeScanner,
    BarcodeScannerCapabilities,
    BarcodeScannerDataReceivedEventArgs,
    BarcodeScannerErrorOccurredEventArgs,
    BarcodeScannerImagePreviewReceivedEventArgs,
    BarcodeScannerReport,
    BarcodeScannerStatusUpdatedEventArgs,
    BarcodeSymbologies,
    BarcodeSymbologyAttributes,
    CashDrawer,
    CashDrawerCapabilities,
    CashDrawerCloseAlarm,
    CashDrawerClosedEventArgs,
    CashDrawerEventSource,
    CashDrawerOpenedEventArgs,
    CashDrawerStatus,
    CashDrawerStatusUpdatedEventArgs,
    ClaimedBarcodeScanner,
    ClaimedBarcodeScannerClosedEventArgs,
    ClaimedCashDrawer,
    ClaimedCashDrawerClosedEventArgs,
    ClaimedJournalPrinter,
    ClaimedLineDisplay,
    ClaimedLineDisplayClosedEventArgs,
    ClaimedMagneticStripeReader,
    ClaimedMagneticStripeReaderClosedEventArgs,
    ClaimedPosPrinter,
    ClaimedPosPrinterClosedEventArgs,
    ClaimedReceiptPrinter,
    ClaimedSlipPrinter,
    JournalPrintJob,
    JournalPrinterCapabilities,
    LineDisplay,
    LineDisplayAttributes,
    LineDisplayCapabilities,
    LineDisplayCursor,
    LineDisplayCursorAttributes,
    LineDisplayCustomGlyphs,
    LineDisplayMarquee,
    LineDisplayStatisticsCategorySelector,
    LineDisplayStatusUpdatedEventArgs,
    LineDisplayStoredBitmap,
    LineDisplayWindow,
    MagneticStripeReader,
    MagneticStripeReaderAamvaCardDataReceivedEventArgs,
    MagneticStripeReaderBankCardDataReceivedEventArgs,
    MagneticStripeReaderCapabilities,
    MagneticStripeReaderCardTypes,
    MagneticStripeReaderEncryptionAlgorithms,
    MagneticStripeReaderErrorOccurredEventArgs,
    MagneticStripeReaderReport,
    MagneticStripeReaderStatusUpdatedEventArgs,
    MagneticStripeReaderTrackData,
    MagneticStripeReaderVendorSpecificCardDataReceivedEventArgs,
    PosPrinter,
    PosPrinterCapabilities,
    PosPrinterCharacterSetIds,
    PosPrinterFontProperty,
    PosPrinterPrintOptions,
    PosPrinterReleaseDeviceRequestedEventArgs,
    PosPrinterStatus,
    PosPrinterStatusUpdatedEventArgs,
    ReceiptPrintJob,
    ReceiptPrinterCapabilities,
    SlipPrintJob,
    SlipPrinterCapabilities,
    UnifiedPosErrorData,
    _ICashDrawerEventSourceEventArgs,
    ICashDrawerEventSourceEventArgs,
    _ICommonClaimedPosPrinterStation,
    ICommonClaimedPosPrinterStation,
    _ICommonPosPrintStationCapabilities,
    ICommonPosPrintStationCapabilities,
    _ICommonReceiptSlipCapabilities,
    ICommonReceiptSlipCapabilities,
    _IPosPrinterJob,
    IPosPrinterJob,
    _IReceiptOrSlipJob,
    IReceiptOrSlipJob,
)

__all__ = [
    "BarcodeScannerStatus",
    "BarcodeSymbologyDecodeLengthKind",
    "CashDrawerStatusKind",
    "LineDisplayCursorType",
    "LineDisplayDescriptorState",
    "LineDisplayHorizontalAlignment",
    "LineDisplayMarqueeFormat",
    "LineDisplayPowerStatus",
    "LineDisplayScrollDirection",
    "LineDisplayTextAttribute",
    "LineDisplayTextAttributeGranularity",
    "LineDisplayVerticalAlignment",
    "MagneticStripeReaderAuthenticationLevel",
    "MagneticStripeReaderAuthenticationProtocol",
    "MagneticStripeReaderErrorReportingType",
    "MagneticStripeReaderStatus",
    "MagneticStripeReaderTrackErrorType",
    "MagneticStripeReaderTrackIds",
    "PosConnectionTypes",
    "PosPrinterAlignment",
    "PosPrinterBarcodeTextPosition",
    "PosPrinterCartridgeSensors",
    "PosPrinterColorCapabilities",
    "PosPrinterColorCartridge",
    "PosPrinterLineDirection",
    "PosPrinterLineStyle",
    "PosPrinterMapMode",
    "PosPrinterMarkFeedCapabilities",
    "PosPrinterMarkFeedKind",
    "PosPrinterPrintSide",
    "PosPrinterRotation",
    "PosPrinterRuledLineCapabilities",
    "PosPrinterStatusKind",
    "UnifiedPosErrorReason",
    "UnifiedPosErrorSeverity",
    "UnifiedPosHealthCheckLevel",
    "UnifiedPosPowerReportingType",
    "SizeUInt32",
    "BarcodeScanner",
    "BarcodeScannerCapabilities",
    "BarcodeScannerDataReceivedEventArgs",
    "BarcodeScannerErrorOccurredEventArgs",
    "BarcodeScannerImagePreviewReceivedEventArgs",
    "BarcodeScannerReport",
    "BarcodeScannerStatusUpdatedEventArgs",
    "BarcodeSymbologies",
    "BarcodeSymbologyAttributes",
    "CashDrawer",
    "CashDrawerCapabilities",
    "CashDrawerCloseAlarm",
    "CashDrawerClosedEventArgs",
    "CashDrawerEventSource",
    "CashDrawerOpenedEventArgs",
    "CashDrawerStatus",
    "CashDrawerStatusUpdatedEventArgs",
    "ClaimedBarcodeScanner",
    "ClaimedBarcodeScannerClosedEventArgs",
    "ClaimedCashDrawer",
    "ClaimedCashDrawerClosedEventArgs",
    "ClaimedJournalPrinter",
    "ClaimedLineDisplay",
    "ClaimedLineDisplayClosedEventArgs",
    "ClaimedMagneticStripeReader",
    "ClaimedMagneticStripeReaderClosedEventArgs",
    "ClaimedPosPrinter",
    "ClaimedPosPrinterClosedEventArgs",
    "ClaimedReceiptPrinter",
    "ClaimedSlipPrinter",
    "JournalPrintJob",
    "JournalPrinterCapabilities",
    "LineDisplay",
    "LineDisplayAttributes",
    "LineDisplayCapabilities",
    "LineDisplayCursor",
    "LineDisplayCursorAttributes",
    "LineDisplayCustomGlyphs",
    "LineDisplayMarquee",
    "LineDisplayStatisticsCategorySelector",
    "LineDisplayStatusUpdatedEventArgs",
    "LineDisplayStoredBitmap",
    "LineDisplayWindow",
    "MagneticStripeReader",
    "MagneticStripeReaderAamvaCardDataReceivedEventArgs",
    "MagneticStripeReaderBankCardDataReceivedEventArgs",
    "MagneticStripeReaderCapabilities",
    "MagneticStripeReaderCardTypes",
    "MagneticStripeReaderEncryptionAlgorithms",
    "MagneticStripeReaderErrorOccurredEventArgs",
    "MagneticStripeReaderReport",
    "MagneticStripeReaderStatusUpdatedEventArgs",
    "MagneticStripeReaderTrackData",
    "MagneticStripeReaderVendorSpecificCardDataReceivedEventArgs",
    "PosPrinter",
    "PosPrinterCapabilities",
    "PosPrinterCharacterSetIds",
    "PosPrinterFontProperty",
    "PosPrinterPrintOptions",
    "PosPrinterReleaseDeviceRequestedEventArgs",
    "PosPrinterStatus",
    "PosPrinterStatusUpdatedEventArgs",
    "ReceiptPrintJob",
    "ReceiptPrinterCapabilities",
    "SlipPrintJob",
    "SlipPrinterCapabilities",
    "UnifiedPosErrorData",
    "ICashDrawerEventSourceEventArgs",
    "ICommonClaimedPosPrinterStation",
    "ICommonPosPrintStationCapabilities",
    "ICommonReceiptSlipCapabilities",
    "IPosPrinterJob",
    "IReceiptOrSlipJob",
]

class BarcodeScannerStatus(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class BarcodeSymbologyDecodeLengthKind(enum.IntEnum):
    ANY_LENGTH = 0
    DISCRETE = 1
    RANGE = 2

class CashDrawerStatusKind(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class LineDisplayCursorType(enum.IntEnum):
    NONE = 0
    BLOCK = 1
    HALF_BLOCK = 2
    UNDERLINE = 3
    REVERSE = 4
    OTHER = 5

class LineDisplayDescriptorState(enum.IntEnum):
    OFF = 0
    ON = 1
    BLINK = 2

class LineDisplayHorizontalAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2

class LineDisplayMarqueeFormat(enum.IntEnum):
    NONE = 0
    WALK = 1
    PLACE = 2

class LineDisplayPowerStatus(enum.IntEnum):
    UNKNOWN = 0
    ONLINE = 1
    OFF = 2
    OFFLINE = 3
    OFF_OR_OFFLINE = 4

class LineDisplayScrollDirection(enum.IntEnum):
    UP = 0
    DOWN = 1
    LEFT = 2
    RIGHT = 3

class LineDisplayTextAttribute(enum.IntEnum):
    NORMAL = 0
    BLINK = 1
    REVERSE = 2
    REVERSE_BLINK = 3

class LineDisplayTextAttributeGranularity(enum.IntEnum):
    NOT_SUPPORTED = 0
    ENTIRE_DISPLAY = 1
    PER_CHARACTER = 2

class LineDisplayVerticalAlignment(enum.IntEnum):
    TOP = 0
    CENTER = 1
    BOTTOM = 2

class MagneticStripeReaderAuthenticationLevel(enum.IntEnum):
    NOT_SUPPORTED = 0
    OPTIONAL = 1
    REQUIRED = 2

class MagneticStripeReaderAuthenticationProtocol(enum.IntEnum):
    NONE = 0
    CHALLENGE_RESPONSE = 1

class MagneticStripeReaderErrorReportingType(enum.IntEnum):
    CARD_LEVEL = 0
    TRACK_LEVEL = 1

class MagneticStripeReaderStatus(enum.IntEnum):
    UNAUTHENTICATED = 0
    AUTHENTICATED = 1
    EXTENDED = 2

class MagneticStripeReaderTrackErrorType(enum.IntEnum):
    NONE = 0
    START_SENTINEL_ERROR = 1
    END_SENTINEL_ERROR = 2
    PARITY_ERROR = 3
    LRC_ERROR = 4
    UNKNOWN = -1

class MagneticStripeReaderTrackIds(enum.IntEnum):
    NONE = 0
    TRACK1 = 1
    TRACK2 = 2
    TRACK3 = 4
    TRACK4 = 8

class PosConnectionTypes(enum.IntFlag):
    LOCAL = 0x1
    IP = 0x2
    BLUETOOTH = 0x4
    ALL = 0xFFFFFFFF

class PosPrinterAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2

class PosPrinterBarcodeTextPosition(enum.IntEnum):
    NONE = 0
    ABOVE = 1
    BELOW = 2

class PosPrinterCartridgeSensors(enum.IntFlag):
    NONE = 0x0
    REMOVED = 0x1
    EMPTY = 0x2
    HEAD_CLEANING = 0x4
    NEAR_END = 0x8

class PosPrinterColorCapabilities(enum.IntFlag):
    NONE = 0x0
    PRIMARY = 0x1
    CUSTOM1 = 0x2
    CUSTOM2 = 0x4
    CUSTOM3 = 0x8
    CUSTOM4 = 0x10
    CUSTOM5 = 0x20
    CUSTOM6 = 0x40
    CYAN = 0x80
    MAGENTA = 0x100
    YELLOW = 0x200
    FULL = 0x400

class PosPrinterColorCartridge(enum.IntEnum):
    UNKNOWN = 0
    PRIMARY = 1
    CUSTOM1 = 2
    CUSTOM2 = 3
    CUSTOM3 = 4
    CUSTOM4 = 5
    CUSTOM5 = 6
    CUSTOM6 = 7
    CYAN = 8
    MAGENTA = 9
    YELLOW = 10

class PosPrinterLineDirection(enum.IntEnum):
    HORIZONTAL = 0
    VERTICAL = 1

class PosPrinterLineStyle(enum.IntEnum):
    SINGLE_SOLID = 0
    DOUBLE_SOLID = 1
    BROKEN = 2
    CHAIN = 3

class PosPrinterMapMode(enum.IntEnum):
    DOTS = 0
    TWIPS = 1
    ENGLISH = 2
    METRIC = 3

class PosPrinterMarkFeedCapabilities(enum.IntFlag):
    NONE = 0x0
    TO_TAKE_UP = 0x1
    TO_CUTTER = 0x2
    TO_CURRENT_TOP_OF_FORM = 0x4
    TO_NEXT_TOP_OF_FORM = 0x8

class PosPrinterMarkFeedKind(enum.IntEnum):
    TO_TAKE_UP = 0
    TO_CUTTER = 1
    TO_CURRENT_TOP_OF_FORM = 2
    TO_NEXT_TOP_OF_FORM = 3

class PosPrinterPrintSide(enum.IntEnum):
    UNKNOWN = 0
    SIDE1 = 1
    SIDE2 = 2

class PosPrinterRotation(enum.IntEnum):
    NORMAL = 0
    RIGHT90 = 1
    LEFT90 = 2
    ROTATE180 = 3

class PosPrinterRuledLineCapabilities(enum.IntFlag):
    NONE = 0x0
    HORIZONTAL = 0x1
    VERTICAL = 0x2

class PosPrinterStatusKind(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class UnifiedPosErrorReason(enum.IntEnum):
    UNKNOWN_ERROR_REASON = 0
    NO_SERVICE = 1
    DISABLED = 2
    ILLEGAL = 3
    NO_HARDWARE = 4
    CLOSED = 5
    OFFLINE = 6
    FAILURE = 7
    TIMEOUT = 8
    BUSY = 9
    EXTENDED = 10

class UnifiedPosErrorSeverity(enum.IntEnum):
    UNKNOWN_ERROR_SEVERITY = 0
    WARNING = 1
    RECOVERABLE = 2
    UNRECOVERABLE = 3
    ASSISTANCE_REQUIRED = 4
    FATAL = 5

class UnifiedPosHealthCheckLevel(enum.IntEnum):
    UNKNOWN_HEALTH_CHECK_LEVEL = 0
    P_O_S_INTERNAL = 1
    EXTERNAL = 2
    INTERACTIVE = 3

class UnifiedPosPowerReportingType(enum.IntEnum):
    UNKNOWN_POWER_REPORTING_TYPE = 0
    STANDARD = 1
    ADVANCED = 2

